@@ -128,7 +128,7 @@ class RemoteTableDataStore(RemoteStore):
         if rows_response.status_code == 200:
             return rows_response.json()
         else:
-            logger.error("Unable to get table from remote store [" + rows_response.text + "], response " + str(
+            logger.warning("Unable to get table from remote store [" + rows_response.text + "], response " + str(
                 rows_response.status_code))
             raise Exception("Unable to get table from remote store  [" + rows_response.text + "], response " + str(
                 rows_response.status_code))
@@ -154,7 +154,7 @@ class RemoteTableDataStore(RemoteStore):
         if doc.status_code == 200:
             return
         else:
-            logger.error("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
+            logger.warning("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
             raise Exception("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
 
     def add(self, row):
@@ -185,7 +185,7 @@ class RemoteTableDataStore(RemoteStore):
         if doc.status_code == 200:
             return
         else:
-            logger.error("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
+            logger.warning("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
             raise Exception("Unable to post rows to remote store [" + doc.text + "], response " + str(doc.status_code))
 
 
@@ -300,7 +300,8 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             logger.info(f"Deleting document family at path {path}")
 
             document_family_response = requests.delete(
-                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs",
+                params={"path": path},
                 headers={"x-access-token": KodexaPlatform.get_access_token()}, )
 
             if document_family_response.status_code == 200:
@@ -308,7 +309,7 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             else:
                 return False
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to decode the JSON response")
             raise
 
@@ -325,10 +326,10 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             else:
                 msg = "Get document family failed [" + document_family_response.text + "], response " + str(
                     document_family_response.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to decode the JSON response")
             raise
 
@@ -353,10 +354,10 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             else:
                 msg = "Document family create failed [" + document_family_response.text + "], response " + str(
                     document_family_response.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to decode the JSON response")
             raise
 
@@ -408,10 +409,10 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             else:
                 msg = "Document replace failed [" + content_object_replace.text + "], response " + str(
                     content_object_replace.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to decode the JSON response")
             raise
 
@@ -423,7 +424,8 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             files = {"document": document.to_kddb()}
             data = {"path": path, "documentVersion": document.version}
             document_family_response = requests.post(
-                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs",
+                params={"path": path},
                 headers={"x-access-token": KodexaPlatform.get_access_token()},
                 files=files, data=data)
 
@@ -432,10 +434,10 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             else:
                 msg = "Document family create failed [" + document_family_response.text + "], response " + str(
                     document_family_response.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to decode the JSON response")
             raise
 
@@ -447,7 +449,8 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             files = {"file": content}
             data = {"path": path}
             document_family_response = requests.post(
-                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs",
+                params={"path": path},
                 headers={"x-access-token": KodexaPlatform.get_access_token()},
                 files=files, data=data)
 
@@ -456,15 +459,16 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             else:
                 msg = "Document family create failed [" + document_family_response.text + "], response " + str(
                     document_family_response.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to decode the JSON response")
             raise
 
     def get_family_by_path(self, path: str) -> Optional[DocumentFamily]:
-        get_response = self._base_get(f"api/stores/{self.ref.replace(':', '/')}/fs/{path}", params={"meta": True})
+        get_response = self._base_get(f"api/stores/{self.ref.replace(':', '/')}/fs",
+                                      params={"path": path, "meta": True})
         return DocumentFamily.from_dict(get_response.json()) if get_response is not None else None
 
     def count(self) -> int:
@@ -501,7 +505,7 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
             return None
         else:
             msg = "Get failed [" + get_response.text + "], response " + str(get_response.status_code)
-            logger.error(msg)
+            logger.warning(msg)
             raise Exception(msg)
 
 
@@ -544,7 +548,8 @@ class RemoteModelStore(ModelStore, RemoteStore):
         from kodexa import KodexaPlatform
         import requests
         resp = requests.delete(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{object_path}",
+            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs",
+            params={"path": object_path},
             headers={"x-access-token": KodexaPlatform.get_access_token()})
 
         if resp.status_code == 200:
@@ -553,7 +558,7 @@ class RemoteModelStore(ModelStore, RemoteStore):
             return False
         else:
             msg = f"Unable to delete model object {resp.text}, status : {resp.status_code}"
-            logger.error(msg)
+            logger.warning(msg)
             raise Exception(msg)
 
     def get(self, object_path: str):
@@ -570,14 +575,15 @@ class RemoteModelStore(ModelStore, RemoteStore):
         from kodexa import KodexaPlatform
         import requests
         resp = requests.get(
-            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{object_path}",
+            f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs",
+            params={"path": object_path},
             headers={"x-access-token": KodexaPlatform.get_access_token()})
 
         if resp.status_code == 200:
             return resp.content
         else:
             msg = f"Unable to get model object {resp.text}, status : {resp.status_code}"
-            logger.error(msg)
+            logger.warning(msg)
             raise Exception(msg)
 
     def put(self, path: str, content) -> DocumentFamily:
@@ -595,7 +601,8 @@ class RemoteModelStore(ModelStore, RemoteStore):
         try:
             files = {"file": content}
             content_object_response = requests.post(
-                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs",
+                params={"path": path},
                 headers={"x-access-token": KodexaPlatform.get_access_token()},
                 files=files)
 
@@ -610,10 +617,10 @@ class RemoteModelStore(ModelStore, RemoteStore):
             else:
                 msg = "Execution creation failed [" + content_object_response.text + "], response " + str(
                     content_object_response.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to JSON decode the response?")
             raise
 
@@ -642,10 +649,10 @@ class RemoteModelStore(ModelStore, RemoteStore):
             else:
                 msg = "Execution creation failed [" + content_object_response.text + "], response " + str(
                     content_object_response.status_code)
-                logger.error(msg)
+                logger.warning(msg)
                 raise Exception(msg)
         except JSONDecodeError:
-            logger.error(
+            logger.warning(
                 "Unable to JSON decode the response?")
             raise
 
@@ -665,5 +672,5 @@ class RemoteModelStore(ModelStore, RemoteStore):
             return ModelContentMetadata.from_dict(resp.json())
         else:
             msg = f"Unable to get model object {resp.text}, status : {resp.status_code}"
-            logger.error(msg)
+            logger.warning(msg)
             raise Exception(msg)
